<!DOCTYPE html>
<!--[if lt IE 7]> <html class="no-js lt-ie9 lt-ie8 lt-ie7" lang="{{ page_lang.language_name }}"> <![endif]-->
<!--[if IE 7]>    <html class="no-js lt-ie9 lt-ie8" lang="{{ page_lang.language_name }}"> <![endif]-->
<!--[if IE 8]>    <html class="no-js lt-ie9" lang="{{ page_lang.language_name }}"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js" lang="{{ page_lang.language_name }}"> <!--<![endif]-->
<head>
    <meta charset="utf-8">
    <title>{{ SITE.name }}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    {% block head_base_css %}
        {% assets "app_css" %}
            <link rel="stylesheet" href="{{ ASSET_URL }}">
        {% endassets %}
    {% endblock %}
    {% block head_more_css %}{% endblock %}
    
    {% block head_base_js %}
        {% assets "modernizr_js" %}
            <script src="{{ ASSET_URL }}"></script>
        {% endassets %}
    {% endblock %}
    {% block head_more_js %}{% endblock %}
</head>

<body class="lang-{{ page_lang.language_name }}"{% block body_attrs %}{% endblock %}>
    {% block base_content %}{% endblock %}
    {% block foot_base_js %}
        {% assets "app_js" %}
            <script src="{{ ASSET_URL }}"></script>
        {% endassets %}
    {% endblock %}
    {% block foot_more_js %}{% endblock %}
</body>
</html>
